@@ -1,5 +1,4 @@
-using Pkg
-Pkg.add("FiniteDifferences")
+include("../../testutils.jl")
 
 using DifferentiationInterface, DifferentiationInterfaceTest
 using FiniteDifferences: FiniteDifferences
@@ -8,8 +7,6 @@ using Test
 using ExplicitImports
 check_no_implicit_imports(DifferentiationInterface)
 
-LOGGING = get(ENV, "CI", "false") == "false"
-
 for backend in [AutoFiniteDifferences(; fdm = FiniteDifferences.central_fdm(3, 1))]
     @test check_available(backend)
     @test !check_inplace(backend)
