@@ -1,5 +1,4 @@
-using Pkg
-Pkg.add("GTPSA")
+include("../../testutils.jl")
 
 using DifferentiationInterface, DifferentiationInterfaceTest
 using GTPSA: GTPSA
@@ -8,8 +7,6 @@ using Test
 using ExplicitImports
 check_no_implicit_imports(DifferentiationInterface)
 
-LOGGING = get(ENV, "CI", "false") == "false"
-
 for backend in [AutoGTPSA()]
     @test check_available(backend)
     @test check_inplace(backend)
