@@ -1,5 +1,4 @@
-using Pkg
-Pkg.add("Tracker")
+include("../../testutils.jl")
 
 using DifferentiationInterface, DifferentiationInterfaceTest
 using Tracker: Tracker
@@ -8,8 +7,6 @@ using Test
 using ExplicitImports
 check_no_implicit_imports(DifferentiationInterface)
 
-LOGGING = get(ENV, "CI", "false") == "false"
-
 for backend in [AutoTracker()]
     @test check_available(backend)
     @test !check_inplace(backend)
